import bpy

# Your main function that contains the logic for creating constraints
def main(context, neighbors_count=5, max_connections=10):
    wm = context.window_manager
    total_objects = len(context.selected_objects)
    total = total_objects * (neighbors_count if neighbors_count < total_objects else total_objects - 1)
    
    counter = 0
    wm.progress_begin(0, total)

    new_collection = bpy.data.collections.new(context.object.name.replace('fractures','connections'))
    bpy.context.scene.collection.children.link(new_collection)
         
    def create_constraint(obj_a, obj_b):
        
        # Create an empty at the midpoint between obj_a and obj_b
        midpoint = (obj_a.location + obj_b.location) / 2
        empty = bpy.data.objects.new("Empty_" + obj_a.name + "_" + obj_b.name, None)
        bpy.context.collection.objects.link(empty)
        empty.location = midpoint

        


        # Create a rigid body constraint
        constraint = bpy.data.objects.new("RBC_" + obj_a.name + "_" + obj_b.name, None)
        bpy.context.collection.objects.link(constraint)

        for coll in constraint.users_collection:
                coll.objects.unlink(constraint)

        new_collection.objects.link(constraint)

        # Set the constraint properties
        constraint.empty_display_size = 0.3
        constraint.empty_display_type = 'ARROWS'
        constraint.parent = obj_a

        # Add rigid body constraint physics
        bpy.context.view_layer.objects.active = constraint
        bpy.ops.rigidbody.constraint_add()
        constraint.rigid_body_constraint.object1 = obj_a
        constraint.location = obj_a.location
        constraint.rigid_body_constraint.object2 = obj_b
        constraint.rigid_body_constraint.type = 'FIXED'

        return constraint, empty

    def find_nearest_neighbors(obj, objects, count):
        distances = [(target, (obj.location - target.location).length) for target in objects if target != obj]
        distances.sort(key=lambda x: x[1])
        return [item[0] for item in distances[:count]]

    def setup_constraints(neighbors_count, max_connections, counter):
        selected_objects = bpy.context.selected_objects
        connections_made = {obj: 0 for obj in selected_objects}
        created_empties = []

        for obj in selected_objects:
            nearest_neighbors = find_nearest_neighbors(obj, selected_objects, neighbors_count)
            for neighbor in nearest_neighbors:
                if connections_made[obj] < max_connections and connections_made[neighbor] < max_connections:
                    constraint, empty = create_constraint(obj, neighbor)
                    created_empties.append(empty)
                    connections_made[obj] += 1
                    connections_made[neighbor] += 1
                    counter += 1
                    wm.progress_update(counter)

        # Remove any empties without constraints
        for empty in created_empties:
            if not empty.children:
                bpy.data.objects.remove(empty)

        print("Processing complete.")

    # Adjust the number of neighbors and the maximum connections as needed
    setup_constraints(10, 10,counter)
    return new_collection


def get_mods():
    if bpy.context.object:
        if 'Q_des_mods' in bpy.context.object:
            if 'mods_list' in bpy.context.object['Q_des_mods']:
                return bpy.context.object['Q_des_mods']['mods_list']