import bpy
from .functions import *
from .operators import *


class QuickDestroyPanel(bpy.types.Panel):
    bl_label = "Quick Destroy"
    bl_idname = "PT_QuickDestroy"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Quick Destroy'

    def draw(self, context):
        layout = self.layout

        # Fracture button
        box1 = layout.box()
        box1.label(text='Fracturing:')
        if get_mods():
            mods = context.object.modifiers

            box = box1.box()
            box.label(text='Subdivisions:')
            box.prop(mods['Q_desubs'], 'levels', text = 'Shards:')
            # box.prop(mods['Q_desubs'], 'render_levels', text = 'Render:')

            box = box1.box()
            box.label(text='Shapes:')

            row = box.row()
            row.scale_y=2
            row.operator('object.qd_make_selection', text='toggle Paint').type='WEIGHT'

            box.prop(mods['Q_deci'], 'ratio')
            box.prop(mods['Q_deci'], 'vertex_group_factor', text = 'Weight Factor')

            box = box1.box()
            box.label(text='factures:')
            box.prop(mods['Q_destroy'].particle_system.settings, 'count')
            box.prop(context.object.particle_systems['Q_destroy'], 'seed')
            box.prop(mods['Q_destroy'].particle_system.settings, 'particle_size')
            box.prop(mods['Q_destroy'].particle_system.settings, 'size_random')

            box = box1.box()
            box.label(text='thickness:')
            box.prop(mods['Q_solidfy'], 'thickness')
            box.prop(mods['Q_solidfy'], 'material_offset')
            box.prop(mods['Q_solidfy'], 'material_offset_rim')
           

            row = box1.row()
            row.operator("object.qdest_remove_fractures", text="Remove Fractures")

            row = box1.row()
            row.scale_y=2
            row.operator("object.qdest_make_rigid", text="Seperate Shards ")

        else:
            if context.object:
                if context.object.type == 'MESH':
                    box1.operator("object.quick_destroy_fracture", text="Fracture")

                box1 = layout.box()
                box1.label(text='Fractures:')
                box1.operator('object.select_grouped', text='select Group').type='COLLECTION'
               
                box1.operator('rigidbody.objects_add', text='Active Rigid').type='ACTIVE'
                box1.operator('rigidbody.objects_add', text='Passive Rigid').type='PASSIVE'
                
                box1 = layout.box()
                box1.label(text='Connections:')
                
                if context.object.rigid_body:
                    box1.operator("object.make_links_connections", text="Make Connections")
            if context.selected_objects:
                box1.operator("object.qd_make_selection", text="Select constrains only").type='CONSTRAINTS'

classes.append(QuickDestroyPanel)

def register():
    for cls in classes:
        bpy.utils.register_class(cls)
      

def unregister():
    for cls in classes:
        bpy.utils.unregister_class(cls)